@@ -14,6 +14,8 @@ pub enum Value<Ctx, E> {
     Vec(Vec<Value<Ctx, E>>),
     Object(HashMap<Box<str>, Value<Ctx, E>>),
     #[serde(skip)]
+    Void,
+    #[serde(skip)]
     Resolver(Box<dyn Resolver<Ctx, E>>),
 }
 
@@ -31,6 +33,7 @@ impl <Ctx, E> PartialEq for Value<Ctx, E> {
             (Self::String(l0), Self::String(r0)) => l0 == r0,
             (Self::Vec(l0), Self::Vec(r0)) => l0 == r0,
             (Self::Object(l0), Self::Object(r0)) => l0 == r0,
+            (Self::Void, Self::Void) => true,
             (Self::Resolver(l0), Self::Resolver(r0)) => l0 == r0,
             _ => core::mem::discriminant(self) == core::mem::discriminant(other),
         }
